@@ -22,6 +22,8 @@ class HomeWizardEnergy:
 
     _device: Device | None = None
 
+    _lock: asyncio.Lock
+
     def __init__(
         self,
         host: str,
@@ -40,6 +42,8 @@ class HomeWizardEnergy:
         self._close_session = clientsession is None
         self._request_timeout = timeout
 
+        self._lock = asyncio.Lock()
+
     @property
     def host(self) -> str:
         """Return the hostname of the device.
@@ -117,6 +121,8 @@ class HomeWizardEnergy:
     async def _create_clientsession(self) -> None:
         """Create a client session."""
 
+        LOGGER.debug("Creating clientsession")
+
         if self._session is not None:
             raise RuntimeError("Session already exists")
 
@@ -131,8 +137,6 @@ class HomeWizardEnergy:
             connector=connector, timeout=ClientTimeout(total=self._request_timeout)
         )
 
-        # self._session = self._create_clientsession(connector, timeout=ClientTimeout(total=self._request_timeout))
-
     async def __aenter__(self) -> HomeWizardEnergy:
         """Async enter.
 
