@@ -7,11 +7,27 @@ from datetime import datetime
 from enum import StrEnum
 from typing import Any
 
+from awesomeversion import AwesomeVersion
 from mashumaro.config import BaseConfig
 from mashumaro.exceptions import MissingField
 from mashumaro.mixins.orjson import DataClassORJSONMixin
+from mashumaro.types import SerializationStrategy
 
 from .const import LOGGER, MODEL_TO_ID, MODEL_TO_NAME, Model
+from .utils import get_awesome_version
+
+
+class AwesomeVersionSerializationStrategy(SerializationStrategy, use_annotations=True):
+    """Serialization strategy for AwesomeVersion objects."""
+
+    def serialize(self, value: AwesomeVersion) -> str:
+        """Serialize AwesomeVersion object to string."""
+        return str(value)
+
+    def deserialize(self, value: str) -> AwesomeVersion | None:
+        """Deserialize string to AwesomeVersion object."""
+        version = get_awesome_version(value)
+        return version
 
 
 class BaseModel(DataClassORJSONMixin):
@@ -22,6 +38,9 @@ class BaseModel(DataClassORJSONMixin):
         """Mashumaro configuration."""
 
         serialize_by_alias = True
+        serialization_strategy = {  # noqa: RUF012
+            AwesomeVersion: AwesomeVersionSerializationStrategy()
+        }
         omit_none = True
 
 
@@ -66,6 +85,12 @@ class CombinedModels:
                 self.system = System()
             self.system.wifi_ssid = self.measurement.wifi_ssid
 
+        ## measurement.wifi_strength -> system.wifi_strength_pct
+        if self.measurement is not None and self.measurement.wifi_strength is not None:
+            if self.system is None:
+                self.system = System()
+            self.system.wifi_strength_pct = self.measurement.wifi_strength
+
         ## state.brightness -> system.status_led_brightness_pct
         if self.state is not None and self.state.brightness is not None:
             if self.system is None:
@@ -95,7 +120,7 @@ class Device(BaseModel):
     product_name: str = field()
     product_type: str = field()
     serial: str = field()
-    api_version: str = field()
+    api_version: AwesomeVersion = field()
     firmware_version: str = field()
 
     @classmethod
@@ -111,6 +136,14 @@ class Device(BaseModel):
         """Return if the device supports state."""
         return self.product_type == Model.ENERGY_SOCKET
 
+    def supports_cloud_enable(self) -> bool:
+        """Return if the device supports cloud enable/disable."""
+        return self.product_type != Model.BATTERY
+
+    def supports_reboot(self) -> bool:
+        """Return if the device supports reboot."""
+        return self.api_version.major >= 2
+
     def supports_identify(self) -> bool:
         """Return if the device supports identify."""
         return self.product_type not in (
@@ -513,6 +546,8 @@ class SystemUpdate(UpdateBaseModel):
 class System(BaseModel):
     """Represent System config."""
 
+    wifi_strength_pct: int | None = None
+
     wifi_ssid: str | None = field(default=None)
     wifi_rssi_db: int | None = field(default=None)
     cloud_enabled: bool | None = field(default=None)
@@ -520,6 +555,21 @@ class System(BaseModel):
     status_led_brightness_pct: int | None = field(default=None)
     api_v1_enabled: bool | None = field(default=None)
 
+    @classmethod
+    def __post_deserialize__(cls, obj: System) -> System:
+        _ = cls  # Unused
+
+        if obj.wifi_rssi_db is not None:
+            obj.wifi_strength_pct = (
+                0
+                if obj.wifi_rssi_db <= -100 or obj.wifi_rssi_db == 0
+                else 100
+                if obj.wifi_rssi_db >= -50
+                else 2 * (obj.wifi_rssi_db + 100)
+            )
+
+        return obj
+
 
 @dataclass(kw_only=True)
 class Token(BaseModel):
